diff --git a/admin/cat_move.php b/admin/cat_move.php
index 83f026d68..d33de8ff0 100644
--- a/admin/cat_move.php
+++ b/admin/cat_move.php
@@ -53,7 +53,7 @@ if (isset($_POST['submit']))
{
array_push(
$page['errors'],
- l10n('Select at least one category')
+ l10n('Select at least one album')
);
}
}
diff --git a/admin/include/functions.php b/admin/include/functions.php
index 5a65f9995..718fa7236 100644
--- a/admin/include/functions.php
+++ b/admin/include/functions.php
@@ -1062,7 +1062,7 @@ SELECT uppercats
{
array_push(
$page['errors'],
- l10n('You cannot move a category in its own sub category')
+ l10n('You cannot move a album in its own sub album')
);
return;
}
@@ -1172,7 +1172,7 @@ function create_virtual_category($category_name, $parent_id=null)
// is the given category name only containing blank spaces ?
if (preg_match('/^\s*$/', $category_name))
{
- return array('error' => l10n('The name of a category should not be empty'));
+ return array('error' => l10n('The name of an album must not be empty'));
}
$parent_id = !empty($parent_id) ? $parent_id : 'NULL';
diff --git a/admin/themes/default/template/cat_list.tpl b/admin/themes/default/template/cat_list.tpl
index 4bb4dccfe..c7007c8b2 100644
--- a/admin/themes/default/template/cat_list.tpl
+++ b/admin/themes/default/template/cat_list.tpl
@@ -68,24 +68,24 @@
{if cat_admin_access($category.ID)}
- 
+ 
{/if}

{if isset($category.U_MANAGE_ELEMENTS) }
- 
+ 
{/if}
- 
+ 
{if isset($category.U_MANAGE_PERMISSIONS) }
- 
+ 
{/if}
{if isset($category.U_DELETE) }
- 
+ 
{/if}
- {$category.NAME}
+ {$category.NAME}
{if $category.IS_VIRTUAL}
{/if}
diff --git a/admin/themes/default/template/cat_modify.tpl b/admin/themes/default/template/cat_modify.tpl
index df21bbe82..2eac97f9a 100644
--- a/admin/themes/default/template/cat_modify.tpl
+++ b/admin/themes/default/template/cat_modify.tpl
@@ -10,18 +10,18 @@
{if cat_admin_access($CAT_ID)}
- 
+ 
{/if}
{if isset($U_MANAGE_ELEMENTS) }
- 
+ 

{/if}
- 
+ 
{if isset($U_MANAGE_PERMISSIONS) }
- 
+ 
{/if}
{if isset($U_DELETE) }
- 
+ 
{/if}
@@ -152,7 +152,7 @@
diff --git a/admin/cat_modify.php b/admin/cat_modify.php
index 50fc21a29..34242fafe 100644
--- a/admin/cat_modify.php
+++ b/admin/cat_modify.php
@@ -111,7 +111,7 @@ UPDATE '.CATEGORIES_TABLE.' SET image_order='.(isset($image_order) ? 'NULL':'\''
move_categories( array($_GET['cat_id']), $_POST['parent'] );
}
- array_push($page['infos'], l10n('Category informations updated successfully.'));
+ array_push($page['infos'], l10n('Album updated successfully'));
}
elseif (isset($_POST['set_random_representant']))
{
@@ -154,7 +154,7 @@ elseif (isset($_POST['submitAdd']))
array_push(
$page['infos'],
sprintf(
- l10n('Category elements associated to the following categories: %s'),
+ l10n('Album elements associated to the following albums: %s'),
'
- '
.get_cat_display_name_from_id($output_create['id'])
.'
'
@@ -183,7 +183,7 @@ elseif (isset($_POST['submitDestinations'])
array_push(
$page['infos'],
sprintf(
- l10n('Category elements associated to the following categories: %s'),
+ l10n('Album elements associated to the following albums: %s'),
'- '.implode('
- ', $category_names).'
'
)
);
@@ -273,7 +273,7 @@ if ('private' == $category['status'])
);
}
// manage category elements link
if ($category['has_images'])
{
$template->assign(
@@ -273,7 +273,7 @@ if ('private' == $category['status'])
);
}
-// manage category elements link
+// manage album elements link
if ($category['has_images'])
{